import type { ResultSet } from "./DB";
import type DB from "./DB";
export type QueryOptions = {
    columns?: string;
    page?: number;
    limit?: number;
    where?: Where;
    order?: string;
};
export type Where = {
    clause: string;
    args?: any[];
};
declare class QueryBuilder {
    db: DB;
    tableName: string;
    private _columns;
    private _whereClause;
    private _whereArgs;
    private _orderBy;
    private _limit;
    private _page;
    constructor(db: DB, tableName: string);
    static query(tableName: string, options: QueryOptions): string;
    static create(tableName: string, object: any): string;
    static createArray(tableName: string, array: any[]): string;
    static update(tableName: string, object: any, whereClause: string): string;
    static destroy(tableName: string, whereClause: string): string;
    static destroyAll(tableName: string): string;
    /**
     * Compila una clausula where
     *
     * @param {any[]} array [1,3,4,2]
     * @returns (?, ?, ?, ?)
     */
    static whereClausePlaceholders(array: any[]): string;
    /**
     * @param sqlString "valor con 'comillas'"
     * @returns "'valor con \'comillas\''"
     */
    static escapeSqlString(sqlString: string, escape?: string): string;
    select(columns: string): this;
    where(clause: string, args: any[]): this;
    orderBy(orderBy: string): this;
    limit(limit: number): this;
    page(page: number): this;
    /**
     * SELECT
     *
     * @returns array de registros
     */
    get(): Promise<any[]>;
    /**
     * INSERT
     *
     * @param {any} values
     * @returns insertId
     */
    insert(values: any): Promise<number>;
    /**
     * INSERT
     *
     * @param {any[]} array
     * @returns result
     */
    insertArray(array: any[]): Promise<ResultSet>;
    /**
     * UPDATE
     *
     * @param {any} values
     * @returns rowsAffected
     */
    update(values: any): Promise<number>;
    /**
     * DELETE
     *
     * @returns rowsAffected
     */
    delete(): Promise<number>;
}
export default QueryBuilder;
//# sourceMappingURL=QueryBuilder.d.ts.map